Node-local Concord API.
This module uses the local KV engine explicitly. Data written through this API stays on the current BEAM node and is not submitted to the VSR cluster.
Node-local Concord API.
This module uses the local KV engine explicitly. Data written through this API stays on the current BEAM node and is not submitted to the VSR cluster.